//
//  HelloWorldPlugin.m
//  Hello World Plugin for RapidWeaver
//
//  Created by Daniel Counsell on 28/06/2007.
//  Copyright Realmac Software 2007. All rights reserved.
//

#import "HelloWorldPlugin.h"

@implementation HelloWorldPlugin

///////////////////////////////////////////////////////////////////
//
// Hello World Plugin 
//
// These are the basic object life-cycle methods
//
///////////////////////////////////////////////////////////////////

- (id)init
{
	self = [super init];
	if(self == nil) return nil;
	
	[NSBundle loadNibNamed:@"HelloWorld" owner:self];

    return self;
}

- (void)dealloc
{
	[super dealloc];
}

// On Launch
- (void)awakeFromNib
{
	//Do something here.
}


///////////////////////////////////////////////////////////////////
//
// Save and restore plugin settings
//
// This is where you can save and restore your plugin's data to 
// and from the .rw3 file
//
///////////////////////////////////////////////////////////////////

//Load Data
- (id)initWithCoder:(NSCoder *)aDecoder
{
    if (self = [self init])
	{
		[outputTextField setStringValue:[aDecoder decodeObject]];
    }
    return self;
}

//Save Data
- (void)encodeWithCoder:(NSCoder *)aCoder 
{
	[aCoder encodeObject:[outputTextField stringValue]];
}


///////////////////////////////////////////////////////////////////
//
// Plugin Output
//
// This is where you return your plugin's content to RapidWeaver. 
// 
// Note: These methods will probably be called on a thread other than
// the main one so beware of calling APIs which are not background
// thread safe e.g. AppleScript, some parts of QuickTime, etc
//
///////////////////////////////////////////////////////////////////

- (id)contentHTML:(NSDictionary*)params
{
	return [NSString stringWithFormat:@"<h1>My Cool Plugin</h1><p>%@</p>", [outputTextField stringValue]];
}

- (NSString *)sidebarHTML:(NSDictionary*)params
{
	return @"<h3>My Cool Sidebar</h3>";
}

- (NSArray *)extraFilesNeededInExportFolder:(NSDictionary*)params
{
	//These could be image of javascript files for example
	return nil;
}

///////////////////////////////////////////////////////////////////
//
// Plugin Actions
//
// Such as the action to show the Plugin Options
//
//
///////////////////////////////////////////////////////////////////

//Open the Page Inspector, and show the plugin options
- (IBAction)showOptions:(id)sender;
{
	[self broadcastPluginSettingsRequest]; 
}
	
///////////////////////////////////////////////////////////////////
//
// Plugin boilerplate
//
// This is the basic machinery required of a plugin by RapidWeaver 
// to supply information like the plugin's name and icon
//
///////////////////////////////////////////////////////////////////

+ (BOOL)initializeClass:(NSBundle *)theBundle
{
	static NSBundle *pluginBundle = nil;
	
    if(pluginBundle == nil) pluginBundle = [theBundle retain];
	
	return (pluginBundle != nil);
}

+ (NSEnumerator *)pluginsAvailable;
{	
    id plugin = [[[HelloWorldPlugin alloc] init] autorelease];

	if(plugin == nil) return nil;
	else return [[NSArray arrayWithObject:plugin] objectEnumerator];
}

+ (NSString *)pluginName
{
	NSBundle *mainBundle = [NSBundle bundleForClass:[self class]];
	return NSLocalizedStringFromTableInBundle(@"PluginName", nil, mainBundle, @"Localizable"); 
}

+ (NSString *)pluginAuthor
{
	NSBundle *mainBundle = [NSBundle bundleForClass:[self class]];
	return NSLocalizedStringFromTableInBundle(@"AuthorName", nil, mainBundle, @"Localizable");
}

+ (NSString *)pluginDescription;
{	
	NSBundle *mainBundle = [NSBundle bundleForClass:[self class]];
    return NSLocalizedStringFromTableInBundle(@"PluginDescription", nil, mainBundle, @"Localizable"); 
}

+ (NSImage *)pluginIcon
{ 
	return [[[NSImage alloc] initWithContentsOfFile:[[NSBundle bundleForClass:[self class]] pathForImageResource:@"plugin_icon"]] autorelease]; 
}

- (NSView *)userInteractionAndEditingView
{ 
	return pluginView;
}

- (NSView *)optionsAndConfigurationView 
{ 
	return optionsView;
}

@end